/* Copyright (c) 2012, 2013, 2014 BlackBerry Limited.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import bb.cascades 1.3
import bb.cascades.pickers 1.0

// When the quote is in edit mode, it is possible to change the name.
// This control presents the input fields for editing the name of the entry.
Container {
    id: editName
    
    property alias popis: popisField.text
    property alias odkdy:  odkdyField.value
    property alias dokdy:  dokdyField.value
    property alias obrazek: obrazekD.imageSource
    property alias davka:  davkaField.text
    property alias poznamka:  poznamkaField.text
    property alias pocetdavek:  pocetdavekField.text
    
    signal enableSave(bool enable)
    
    layout: StackLayout {
        orientation: LayoutOrientation.TopToBottom
    }
    Container {
        id: editPane
        property real margins: ui.du(3)
        
        
        topPadding: margins
        leftPadding: margins
        rightPadding: margins
        bottomPadding: margins
        
        layout: DockLayout {
        }
        ScrollView {
            Container {
                layout: StackLayout {
                }
                
                Container {
                    
                    layout: StackLayout {
                        orientation: LayoutOrientation.TopToBottom
                    }
                    Label {
                        text: qsTr("Description") + Retranslate.onLanguageChanged    
                    }
                    TextField {
                        id: popisField
                        onTextChanging: {
                            if (popisField.text.length > 0 && odkdyField.value < dokdyField.value) {
                                enableSave(true);
                            } else {
                                enableSave(false);
                            }
                        
                        }
                    }
                } 
                Container {
                    
                    layout: StackLayout {
                        orientation: LayoutOrientation.TopToBottom
                    }
                    Label {
                        text: qsTr("Dose") + Retranslate.onLanguageChanged    
                    }
                    Container {
                        layout: StackLayout {
                            orientation: LayoutOrientation.LeftToRight
                        
                        }
                        
                        TextField {
                            id: davkaField
                            minWidth: 200.0
                            minHeight: 200.0
                            rightMargin: 20.0
                        }
                        TextField {
                            id: pocetdavekField
                        }
                    
                    
                    }
                }
                Divider {
                
                }
                Container {
                    
                    layout: StackLayout {
                        orientation: LayoutOrientation.TopToBottom
                    }
                    DateTimePicker {
                        id: odkdyField
                        mode: DateTimePickerMode.DateTime
                        onValueChanged: {
                            if (popisField.text.length > 0 && odkdyField.value < dokdyField.value) {
                                editName.enableSave(true);
                            } else {
                                editName.enableSave(false);
                            }
                        }
                        rightMargin: 20.0
                        title: qsTr("From ") + Retranslate.onLanguageChanged
                    }
                    DateTimePicker {
                        id: dokdyField
                        mode: DateTimePickerMode.DateTime
                        onValueChanged: {
                            if (popisField.text.length > 0 && odkdyField.value < dokdyField.value) {
                                editName.enableSave(true);
                            } else {
                                editName.enableSave(false);
                            }
                        }
                        title: qsTr("To ") + Retranslate.onLanguageChanged
                    
                    }            
                }
                Divider {
                
                }
                Container {
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    
                    }
                    
                    DropDown {
                        id: obrazekField
                        title: qsTr("Medication icon") + Retranslate.onLanguageChanged
                        onSelectedIndexChanged: {
                            obrazekD.imageSource = obrazekField.selectedOption.imageSource
                        }
                        Option {
                            imageSource: "asset:///listimages/0.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/1.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/2.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/3.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/4.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/5.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/6.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/7.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/8.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/9.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/10.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/11.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/12.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/12.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/13.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/14.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/15.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/16.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/17.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/18.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/19.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/20.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/21.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/22.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/23.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/24.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/25.png"
                        }
                        Option {
                            imageSource: "asset:///listimages/26.png"
                        }
                    }
                    ImageView {
                        id: obrazekD
                        
                        horizontalAlignment: HorizontalAlignment.Center
                        minWidth: 250.0
                        minHeight: 250.0
                    }
                }
                Label {
                    text: qsTr("Notes") + Retranslate.onLanguageChanged    
                }
                TextField {
                    id: poznamkaField
                }
            }
            
            
            //Total text Container (name text + quote text)
        }

    }
    
    
    
    
    onVisibleChanged: {
        if (visible) {
            // When this component becomes visible we request focus to show the
            // virtual keyboard (if available) and to hint that this field is required.
            popisField.requestFocus();
        }
    }
    horizontalAlignment: HorizontalAlignment.Center
}
