/* Copyright (c) 2012, 2013, 2014 BlackBerry Limited.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import bb.cascades 1.3
import bb.system 1.0

Page {
    id: quotePage
    
    // Data property, this is updated when navigation occurs, has three entries.
    property variant quoteData: 
    { 
        'popis': "Medicine", 'odkdy':new Date(), 'dokdy':new Date(), 'obrazek':"asset:///listimages/pills.png", 'davka':"1",  'poznamka':"", 'pocetdavek':"tablets"}
    
    // Signals for handling data updates triggered from the Quote Page.
    signal deleteQuote();
    signal updateQuote(string npopis, date nodkdy, date ndokdy, string nobrazek, string ndavka, string npoznamka, string npocetdavek);
    signal back();
        
    titleBar: TitleBar {
        title: qsTr("Edit") + Retranslate.onLanguageChanged
        visibility: quoteBubble.editMode ? ChromeVisibility.Visible : ChromeVisibility.Hidden; 
        acceptAction: ActionItem {
            title: qsTr("Save") + Retranslate.onLanguageChanged
        	enabled: quoteBubble.enableSave
            onTriggered: {
                quoteBubble.editMode = false;
                quotePage.updateQuote(quoteBubble.pendingPopis, quoteBubble.pendingOdkdy, quoteBubble.pendingDokdy, quoteBubble.pendingObrazek,
                quoteBubble.pendingDavka, quoteBubble.pendingPoznamka, quoteBubble.pendingPocetdavek);
            }
        }

        dismissAction: ActionItem {
            title: qsTr("Cancel") + Retranslate.onLanguageChanged
            onTriggered: {
                quoteBubble.editMode = false;
                //quoteBubble.quoteText = quotePage.quoteData["quote"];
            }
        }
    }
    
    Container {
        horizontalAlignment: HorizontalAlignment.Center

        QuoteBubble {
            id: quoteBubble
            // Since the data presented in the Quote bubble is connected to the list of quotes
            // and may change (on for example deletion), some of the properties of the QuoteBuble are set in the 
            // onQuoteDataChanged signal handler below.

			horizontalAlignment: HorizontalAlignment.Center
            
        } // QuoteBubble
    } // Container

    shortcuts: [
        SystemShortcut {
            // The edit  short cut puts the Page in edit mode.
            type: SystemShortcuts.Edit
            onTriggered: {
                quoteBubble.editMode = true;
            }
        }
    ]
 
 
    paneProperties: NavigationPaneProperties {
        backButton: ActionItem {
            title: qsTr("Medications") + Retranslate.onLanguageChanged
            onTriggered: {
                quoteBubble.editMode = false;
                quotePage.back();
            }
        }
    }
    
    actions: [
        ActionItem {            
            title: qsTr("Edit") + Retranslate.onLanguageChanged
            imageSource: "asset:///images/Edit.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            enabled: !quoteBubble.editMode

            onTriggered: {
                quoteBubble.editMode = true
            }
        
        
            
        },
        ActionItem {            
            title: qsTr("Create events") + Retranslate.onLanguageChanged
            imageSource: "asset:///images/action_addevent.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            enabled: !quoteBubble.editMode
            
            onTriggered: {
                var Cas1 = new Date();Cas1.setHours(8,0,0);
                var Cas2 = new Date();Cas2.setHours(14,0,0);
                var Cas3 = new Date();Cas3.setHours(20,0,0);
                dp1.value = Cas1;
                dp2.value = Cas2;
                dp3.value = Cas3;
                mySheet.open()
            }
        },
        DeleteActionItem {
            objectName: "DeleteAction"
            
            onTriggered: {
                sdDotaz.show();
            }
        }
    ]
    attachedObjects: [
        //generovani polozek do kalendare
        Sheet {
            id: mySheet
            content: Page {
                titleBar: TitleBar {
                    title: qsTr("Create events for medication") + Retranslate.onLocaleOrLanguageChanged
                    appearance: TitleBarAppearance.Branded
                
                }  
                
                actions: [
                    ActionItem {
                        title: qsTr("Back to detail") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///images/ic_home.png"
                        ActionBar.placement: ActionBarPlacement.Signature
                        
                        // When this action is selected, close
                        // the sheet
                        onTriggered: {
                            QuotesApp.save("CalendarAccount", folderField.selectedIndex);
                            mySheet.close();
                        }
                    }
                ]
                ScrollView {
                    Container {
                        property real margins: ui.du(3)
                        
                        
                        topPadding: margins
                        leftPadding: margins
                        rightPadding: margins
                        bottomPadding: margins
                        
                        DateTimePicker {
                            id: pomdp1
                            value: quoteBubble.odkdy
                            mode: DateTimePickerMode.DateTime
                            accessibilityMode: A11yMode.Collapsed
                            enabled: false
                            title: qsTr("Period from: ") + Retranslate.onLanguageChanged
                            touchPropagationMode: TouchPropagationMode.None
                        }
                        DateTimePicker {
                            id: pomdp2
                            value: quoteBubble.dokdy
                            mode: DateTimePickerMode.DateTime
                            accessibilityMode: A11yMode.Collapsed
                            enabled: false
                            title: qsTr("Period to: ") + Retranslate.onLanguageChanged
                            touchPropagationMode: TouchPropagationMode.None
                        }
                        Divider {
                        
                        }
                        Label {
                            text: qsTr("Generate calendar events: ") + Retranslate.onLanguageChanged
                            horizontalAlignment: HorizontalAlignment.Center
                        }
                        Divider {
                        
                        }
                        DropDown {
                            id: ddMode
                            title: qsTr("Mode: ") + Retranslate.onLanguageChanged
                            selectedIndex: 0
                            onSelectedIndexChanged: {
                                if (selectedIndex == 0) 
                                {cnFixed1.visible = true;cnFixed2.visible = true;cnFixed3.visible = true;cnInterval.visible = false};
                                if (selectedIndex == 1) 
                                {cnFixed1.visible = false;cnFixed2.visible = false;cnFixed3.visible = false;cnInterval.visible = true};
                            }
                            Option {
                                text: qsTr("Based on fixed time") + Retranslate.onLanguageChanged
                            }
                            Option {
                                text: qsTr("Based on time interval") + Retranslate.onLanguageChanged
                            }
                        }
                        Container {
                            id: cnFixed1
                            layout: DockLayout {
                            
                            }
                            horizontalAlignment: HorizontalAlignment.Fill
                            CheckBox {
                                id: cb1
                                checked: true
                                text: qsTr("Every dat at: ") + Retranslate.onLanguageChanged
                                maxWidth: 500.0
                                enabled: false
                            
                            }
                            DateTimePicker {
                                id: dp1
                                mode: DateTimePickerMode.Time
                                maxWidth: 200.0
                                horizontalAlignment: HorizontalAlignment.Right
                            
                            }
                        
                        }
                        Container {
                            id: cnFixed2
                            layout: DockLayout {
                            
                            }
                            horizontalAlignment: HorizontalAlignment.Fill
                            CheckBox {
                                id: cb2
                                checked: false
                                text: qsTr("Every dat at: ") + Retranslate.onLanguageChanged
                                onCheckedChanged: {
                                    dp2.visible = cb2.checked
                                }
                                maxWidth: 500.0
                            
                            
                            }
                            DateTimePicker {
                                id: dp2
                                mode: DateTimePickerMode.Time
                                maxWidth: 200.0
                                visible: false
                                horizontalAlignment: HorizontalAlignment.Right
                            
                            }
                        
                        }
                        Container {
                            id: cnFixed3
                            layout: DockLayout {
                            
                            }
                            horizontalAlignment: HorizontalAlignment.Fill
                            CheckBox {
                                id: cb3
                                checked: false
                                text: qsTr("Every dat at: ") + Retranslate.onLanguageChanged
                                onCheckedChanged: {
                                    dp3.visible = cb3.checked
                                }
                                maxWidth: 500.0
                            
                            }
                            DateTimePicker {
                                id: dp3
                                mode: DateTimePickerMode.Time
                                maxWidth: 200.0
                                visible: false
                                horizontalAlignment: HorizontalAlignment.Right
                            
                            }
                        
                        }
                        
                        Container {
                            id: cnInterval
                            layout: DockLayout {
                            
                            }
                            visible: false
                            DateTimePicker {
                                id: dp4
                                title: qsTr("Every (hours-minutes)") + Retranslate.onLanguageChanged
                                mode: DateTimePickerMode.Time
                                value: new Date(0,0,0,2,0)
                            
                            }
                        
                        }
                        DropDown {
                            id: folderField
                            
                            title: qsTr ("Store in calendar:") + Retranslate.onLanguageChanged
                            
                            onSelectedValueChanged: {
                                _calendar.eventEditor.folderId = selectedValue.folderId
                                _calendar.eventEditor.accountId = selectedValue.accountId
                            }
                        }
                        
                        Divider {
                        
                        }
                        Button {
                            text: qsTr("Create requested events") + Retranslate.onLanguageChanged
                            onClicked: {
                                sdVytvoreni.show();
                            }
                            horizontalAlignment: HorizontalAlignment.Center
                            color: Color.DarkGreen

                        }
                    
                    }
                }

            }
        },
        SystemDialog {
            id: sdDotaz
            title: qsTr("Delete") + Retranslate.onLanguageChanged
            body: qsTr("Delete selected medication ?") + Retranslate.onLanguageChanged
            cancelButton.label: qsTr("Cancel") + Retranslate.onLanguageChanged
            confirmButton.label: qsTr("Delete") + Retranslate.onLanguageChanged
            customButton.enabled: false
            emoticonsEnabled: true
            dismissAutomatically: true
            onFinished: {
                if (buttonSelection()==confirmButton) 
                {
                    quotePage.deleteQuote();
                    quoteBubble.editMode = false
                }
            }
        },
        SystemDialog {
            id: sdVytvoreni
            title: qsTr("Create events") + Retranslate.onLanguageChanged
            body: qsTr("Do you like to create calendar events for this medication ?") + Retranslate.onLanguageChanged
            cancelButton.label: qsTr("Cancel") + Retranslate.onLanguageChanged
            confirmButton.label: qsTr("Create") + Retranslate.onLanguageChanged
            customButton.enabled: false
            emoticonsEnabled: true
            dismissAutomatically: true
            onFinished: {
                         if (buttonSelection()==confirmButton) 
                         {
                          // vytvoreni udalosti v kalendari fixed
                          if (ddMode.selectedIndex == 0)
                          {
                          for (var i = 1; i<=_calendar.PocetDnu(quoteBubble.odkdy, quoteBubble.dokdy); i++)
                           {
                            // seznam 1
                            if (cb1.checked && _calendar.VytvorDatumCas(quoteBubble.odkdy, dp1.value, i) >= quoteBubble.odkdy && _calendar.VytvorDatumCas(quoteBubble.odkdy, dp1.value, i) <= quoteBubble.dokdy)
                            {pridatPolozky(i,_calendar.VytvorDatumCas(quoteBubble.odkdy, dp1.value, i));}
                            // seznam 2
                            if (cb2.checked && _calendar.VytvorDatumCas(quoteBubble.odkdy, dp2.value, i) >= quoteBubble.odkdy && _calendar.VytvorDatumCas(quoteBubble.odkdy, dp2.value, i) <= quoteBubble.dokdy)
                            {pridatPolozky(i,_calendar.VytvorDatumCas(quoteBubble.odkdy, dp2.value, i));}
                            // seznam 3
                            if (cb3.checked && _calendar.VytvorDatumCas(quoteBubble.odkdy, dp3.value, i) >= quoteBubble.odkdy && _calendar.VytvorDatumCas(quoteBubble.odkdy, dp3.value, i) <= quoteBubble.dokdy)
                            {pridatPolozky(i,_calendar.VytvorDatumCas(quoteBubble.odkdy, dp3.value, i));}
                           } //for                 
                          }; // if fixed
                          // vytvoreni udalosti v kalendari interval
                          if (ddMode.selectedIndex == 1)
                          {
                           var ps = dp4.value.getHours()*3600+dp4.value.getMinutes()*60;
                           var pruchod =0;
                           while (_calendar.ZvysDatum(quoteBubble.odkdy, ps*pruchod)<=quoteBubble.dokdy)
                           {pridatPolozkyI(_calendar.ZvysDatum(quoteBubble.odkdy, ps*pruchod));
                            pruchod++}
                          }; // if interval
                          
                
                
                          QuotesApp.showSuccessMessage(qsTr("Calendar items have been created") + Retranslate.onLanguageChanged)
                         } // if buttonselection
                        } // onFinished
        }
    
    ]
    
    onQuoteDataChanged: {
        // If the first name is not defined set it to an empty string
        quoteBubble.popis = quotePage.quoteData["popis"]
        quoteBubble.davka = quotePage.quoteData["davka"]
        quoteBubble.pocetdavek = quotePage.quoteData["pocetdavek"]
        quoteBubble.obrazek = quotePage.quoteData["obrazek"]
        quoteBubble.odkdy = quotePage.quoteData["odkdy"]
        quoteBubble.dokdy = quotePage.quoteData["dokdy"]
        quoteBubble.poznamka = quotePage.quoteData["poznamka"]
    }
    
onCreationCompleted: {
    _calendar.eventEditor.initializeFolderDropDown(folderField);
    folderField.selectedIndex=QuotesApp.read("CalendarAccount",0);
}    

function pridatPolozky(pocitadlo, jednotnyCas)
{
    _calendar.eventEditor.subject = quoteBubble.popis;
    _calendar.eventEditor.location = quoteBubble.davka +" "+ quoteBubble.pocetdavek;
    _calendar.eventEditor.startTime = _calendar.VytvorDatumCas(quoteBubble.odkdy, jednotnyCas, pocitadlo);
    _calendar.eventEditor.endTime = _calendar.ZvysDatum(_calendar.VytvorDatumCas(quoteBubble.odkdy, jednotnyCas, pocitadlo),QuotesApp.read("EventLength",60)*60);
    _calendar.eventEditor.folderId = folderField.selectedValue.folderId
    _calendar.eventEditor.accountId = folderField.selectedValue.accountId
    _calendar.eventEditor.saveEvent()
    
}

function pridatPolozkyI(Kdy)
{
    _calendar.eventEditor.subject = quoteBubble.popis;
    _calendar.eventEditor.location = quoteBubble.davka +" "+ quoteBubble.pocetdavek;
    _calendar.eventEditor.startTime = Kdy;
    _calendar.eventEditor.endTime = _calendar.ZvysDatum(Kdy,QuotesApp.read("EventLength",60)*60);
    _calendar.eventEditor.folderId = folderField.selectedValue.folderId
    _calendar.eventEditor.accountId = folderField.selectedValue.accountId
    _calendar.eventEditor.saveEvent()

}
    
}// Quote Page

