/* Copyright (c) 2012, 2013, 2014 BlackBerry Limited.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import bb.cascades 1.3
import bb.cascades.pickers 1.0

// The Edit Screen is where the text areas for editing and completing information for a new
// record is added together with two buttons for add/edit and cancel.
Sheet {
    id: addSheet
    signal addNewRecord(string npopis, date nodkdy, date ndokdy, string nobrazek, string ndavka, string npoznamka, string npocetdavek)

    Page {
        id: addPage
        
        titleBar: TitleBar {
            id: addBar
            title: qsTr("Add medication") + Retranslate.onLanguageChanged
            visibility: ChromeVisibility.Visible
            
            dismissAction: ActionItem {
                title: qsTr("Cancel") + Retranslate.onLanguageChanged
                onTriggered: {
                    addSheet.close()
                }
            }
            
            acceptAction: ActionItem {
                title: qsTr("Save") + Retranslate.onLanguageChanged
                enabled: false
                onTriggered: {
                    addNewRecord(popisField.text, odkdyField.value, dokdyField.value, obrazekD.imageSource, davkaField.text, 
                    poznamkaField.text, pocetdavekField.selectedValue);
                    addSheet.close()
                    QuotesApp.showSuccessMessage(qsTr("New medication has been saved") + Retranslate.onLanguageChanged)
                }
            }
        }
        ScrollView {
            Container {
                id: editPane
                property real margins: ui.du(3)
                
                
                topPadding: margins
                leftPadding: margins
                rightPadding: margins
                bottomPadding: margins
                
                layout: DockLayout {
                }
                
                Container {
                    layout: StackLayout {
                    }
                    
                    Container {
                        
                        layout: StackLayout {
                            orientation: LayoutOrientation.TopToBottom
                        }
                        Label {
                            text: qsTr("Description") + Retranslate.onLanguageChanged    
                        }
                        TextField {
                            id: popisField
                            onTextChanging: {
                                if (popisField.text.length > 0 && odkdyField.value < dokdyField.value) {
                                    addPage.titleBar.acceptAction.enabled = true;
                                } else {
                                    addPage.titleBar.acceptAction.enabled = false;
                                }
                            
                            }
                        }
                        Divider {
                        
                        }
                    }
                    
                    Container {
                        
                        layout: StackLayout {
                            orientation: LayoutOrientation.TopToBottom
                        }
                        Label {
                            text: qsTr("Dose") + Retranslate.onLanguageChanged    
                        }
                        Container {
                            layout: StackLayout {
                                orientation: LayoutOrientation.LeftToRight
                            
                            }
                            
                            DropDown {
                                id: davkaField
                                minWidth: 200.0
                                
                                selectedIndex: 3
                                title: qsTr("Number") + Retranslate.onLanguageChanged
                                Option {
                                    text:qsTr("1/4") + Retranslate.onLanguageChanged
                                    value:qsTr("1/4") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("1/2") + Retranslate.onLanguageChanged
                                    value:qsTr("1/2") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("3/4") + Retranslate.onLanguageChanged
                                    value:qsTr("3/4") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("1") + Retranslate.onLanguageChanged
                                    value:qsTr("1") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("2") + Retranslate.onLanguageChanged
                                    value:qsTr("2") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("3") + Retranslate.onLanguageChanged
                                    value:qsTr("3") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("4") + Retranslate.onLanguageChanged
                                    value:qsTr("4") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("5") + Retranslate.onLanguageChanged
                                    value:qsTr("5") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("6") + Retranslate.onLanguageChanged
                                    value:qsTr("6") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("7") + Retranslate.onLanguageChanged
                                    value:qsTr("7") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("8") + Retranslate.onLanguageChanged
                                    value:qsTr("8") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("9") + Retranslate.onLanguageChanged
                                    value:qsTr("9") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("10") + Retranslate.onLanguageChanged
                                    value:qsTr("10") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("15") + Retranslate.onLanguageChanged
                                    value:qsTr("15") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("20") + Retranslate.onLanguageChanged
                                    value:qsTr("20") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("25") + Retranslate.onLanguageChanged
                                    value:qsTr("25") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("30") + Retranslate.onLanguageChanged
                                    value:qsTr("30") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("40") + Retranslate.onLanguageChanged
                                    value:qsTr("40") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("50") + Retranslate.onLanguageChanged
                                    value:qsTr("50") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("60") + Retranslate.onLanguageChanged
                                    value:qsTr("60") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("70") + Retranslate.onLanguageChanged
                                    value:qsTr("70") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("80") + Retranslate.onLanguageChanged
                                    value:qsTr("80") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("90") + Retranslate.onLanguageChanged
                                    value:qsTr("90") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("100") + Retranslate.onLanguageChanged
                                    value:qsTr("100") + Retranslate.onLanguageChanged 
                                }
                            }
                            
                            
                            DropDown {
                                id: pocetdavekField
                                selectedIndex: 0
                                title: qsTr("Units") + Retranslate.onLanguageChanged
                                Option {
                                    text:qsTr("tablets") + Retranslate.onLanguageChanged
                                    value:qsTr("tablets") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("drops") + Retranslate.onLanguageChanged
                                    value:qsTr("drops") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("pieces") + Retranslate.onLanguageChanged
                                    value:qsTr("pieces") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("mililitres") + Retranslate.onLanguageChanged
                                    value:qsTr("mililitres") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("grams") + Retranslate.onLanguageChanged
                                    value:qsTr("grams") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("centimetres") + Retranslate.onLanguageChanged
                                    value:qsTr("centimetres") + Retranslate.onLanguageChanged 
                                }
                                Option {
                                    text:qsTr("capsules") + Retranslate.onLanguageChanged
                                    value:qsTr("capsules") + Retranslate.onLanguageChanged 
                                }
                            
                            }
                        }
                    }
                    Divider {
                    
                    }
                    Container {
                        
                        layout: StackLayout {
                            orientation: LayoutOrientation.TopToBottom
                        }
                        DateTimePicker {
                            id: odkdyField
                            mode: DateTimePickerMode.DateTime
                            onValueChanged: {
                                if (popisField.text.length > 0 && odkdyField.value < dokdyField.value) {
                                    addPage.titleBar.acceptAction.enabled = true;
                                } else {
                                    addPage.titleBar.acceptAction.enabled = false;
                                }
                            }
                            rightMargin: 20.0
                            title: qsTr("From ") + Retranslate.onLanguageChanged
                        }
                        DateTimePicker {
                            id: dokdyField
                            mode: DateTimePickerMode.DateTime
                            onValueChanged: {
                                if (popisField.text.length > 0 && odkdyField.value < dokdyField.value) {
                                    addPage.titleBar.acceptAction.enabled = true;
                                } else {
                                    addPage.titleBar.acceptAction.enabled = false;
                                }
                            }
                            title: qsTr("To ") + Retranslate.onLanguageChanged
                        
                        }
                    }
                    
                    Divider {
                    
                    }
                    Container {
                        layout: StackLayout {
                            orientation: LayoutOrientation.LeftToRight
                        
                        }
                        
                        DropDown {
                            id: obrazekField
                            title: qsTr("Medication icon") + Retranslate.onLanguageChanged
                            onSelectedIndexChanged: {
                                obrazekD.imageSource = obrazekField.selectedOption.imageSource
                            }
                            Option {
                                imageSource: "asset:///listimages/0.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/1.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/2.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/3.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/4.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/5.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/6.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/7.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/8.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/9.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/10.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/11.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/12.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/13.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/14.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/15.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/16.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/17.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/18.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/19.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/20.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/21.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/22.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/23.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/24.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/25.png"
                            }
                            Option {
                                imageSource: "asset:///listimages/26.png"
                            }
                        }
                        ImageView {
                            id: obrazekD
                            
                            horizontalAlignment: HorizontalAlignment.Center
                            minWidth: 250.0
                            minHeight: 250.0
                            imageSource: "asset:///listimages/pills.png"
                        }
                    }
                    
                    Label {
                        text: qsTr("Notes") + Retranslate.onLanguageChanged
                    }
                    TextField {
                        id: poznamkaField
                    }
                }
                
                //Total text Container (name text + quote text)
            
            } // Content Container
        } // TitleBar
        

    }

    onOpened: {
        // Focus can not be requested until the Sheet is part of the UI-tree, so we
        // wait until it has been shown and request focus for the last name field
        popisField.requestFocus();
    }
}
