/* Copyright (c) 2012, 2013, 2014 BlackBerry Limited.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import bb.cascades 1.3
import bb.cascades.pickers 1.0

// The Edit Screen is where the text areas for editing and completing information for a new
// record is added together with two buttons for add/edit and cancel.
Sheet {
    id: settingsSheet

    Page {
        id: settingsPage
        titleBar: TitleBar {
            id: addBar
            title: qsTr("Settings") + Retranslate.onLanguageChanged
            
            dismissAction: ActionItem {
                title: qsTr("Cancel") + Retranslate.onLanguageChanged
                onTriggered: {
                    settingsSheet.close()
                }
            }
            
            acceptAction: ActionItem {
                title: qsTr("Save") + Retranslate.onLanguageChanged
                enabled: false
                onTriggered: {
                    if (tbTheme.checked==true)
                    {Settings.saveValueFor("theme", "dark");} else
                    {Settings.saveValueFor("theme", "bright");}
                    QuotesApp.save("EventLength", tfLength.text);
                    settingsSheet.close()
                }
            }
        } // TitleBar        
        Container {
            
            property real margins: ui.du(3)
            
            
            topPadding: margins
            leftPadding: margins
            rightPadding: margins
            bottomPadding: margins
            verticalAlignment: VerticalAlignment.Top
            layout: StackLayout {
                orientation: LayoutOrientation.TopToBottom

            }

            Container {
                layout: StackLayout {
                    orientation: LayoutOrientation.LeftToRight

                }
                Label {
                    text: qsTr("Dark theme") + Retranslate.onLanguageChanged
                    verticalAlignment: VerticalAlignment.Top
                
                }
                ToggleButton {
                    id: tbTheme
                    verticalAlignment: VerticalAlignment.Top
                    onCheckedChanged: {
                        addBar.acceptAction.enabled=true   
                    }
                
                
                }
            }
            Divider {

            }
            Container {
                layout: StackLayout {
                    orientation: LayoutOrientation.LeftToRight

                }
                verticalAlignment: VerticalAlignment.Center
                Label {
                    text: qsTr("Event length (minutes)") + Retranslate.onLanguageChanged
                    verticalAlignment: VerticalAlignment.Top
                
                }
                TextField {
                    id: tfLength
                    inputMode: TextFieldInputMode.NumbersAndPunctuation
                
                }
            }

        }
    
    }
    onCreationCompleted: {
        if (Settings.getValueFor("theme", "bright")=="dark")
        {tbTheme.checked=true};
        tfLength.text = QuotesApp.read("EventLength",60)
    }
        
    
}
